[OpenLayers-Commits] r12051 - in trunk/openlayers: lib/OpenLayers/Handler tests/Handler

commits-20090109 at openlayers.org commits-20090109 at openlayers.org
Mon Jun 6 07:43:51 EDT 2011


Author: bartvde
Date: 2011-06-06 04:43:50 -0700 (Mon, 06 Jun 2011)
New Revision: 12051

Modified:
   trunk/openlayers/lib/OpenLayers/Handler/Box.js
   trunk/openlayers/tests/Handler/Box.html
Log:
Box Handler missing start callback, r=pgiraud (closes #3324)

Modified: trunk/openlayers/lib/OpenLayers/Handler/Box.js
===================================================================
--- trunk/openlayers/tests/Handler/Box.html	2011-06-06 11:02:11 UTC (rev 12050)
+++ trunk/openlayers/tests/Handler/Box.html	2011-06-06 11:43:50 UTC (rev 12051)
@@ -3,16 +3,17 @@
   <script src="../OLLoader.js"></script>
   <script type="text/javascript">
     function test_Handler_Box_constructor(t) {
-        t.plan(4);
+        t.plan(5);
         var control = new OpenLayers.Control();
         control.id = Math.random();
-        var callbacks = {done: "bar"};
+        var callbacks = {start: "foo", done: "bar"};
         var options = {bar: "foo"};
         
         var handler = new OpenLayers.Handler.Box(control, callbacks, options);
 
         t.eq(handler.control.id, control.id, "handler created with the correct control");
-        t.eq(handler.callbacks.done, "bar", "handler created with the correct callback");
+        t.eq(handler.callbacks.start, "foo", "handler created with the correct start callback");
+        t.eq(handler.callbacks.done, "bar", "handler created with the correct done callback");
         t.eq(handler.bar, "foo", "handler created with the correct options");
         t.ok(handler.dragHandler instanceof OpenLayers.Handler.Drag, "drag handler created");
     }
@@ -22,9 +23,14 @@
         var map = new OpenLayers.Map('map');
         var control = new OpenLayers.Control();
         map.addControl(control);
-        var handler = new OpenLayers.Handler.Box(control, {done: function(e) {
-            t.ok(e.equals(new OpenLayers.Bounds(5, 11, 11, 5)), "box result correct");
-        }});
+        var handler = new OpenLayers.Handler.Box(control, {
+            start: function(e) {
+                t.ok(true, "start callback called");
+            },
+            done: function(e) {
+                t.ok(e.equals(new OpenLayers.Bounds(5, 11, 11, 5)), "box result correct");
+            }
+        });
         handler.activate();
 
         // determine whether we can test the box position, the hidden frame
@@ -39,7 +45,7 @@
         map.div.removeChild(testdiv);
         var testAll = !isNaN(left);
 
-        t.plan(testAll ? 10 : 2);
+        t.plan(testAll ? 11 : 3);
 
         // we change NaN values to 0 values in the handler's
         // boxOffsets object, this is to prevent "invalid



More information about the Commits mailing list
--- trunk/openlayers/lib/OpenLayers/Handler/Box.js	2011-06-06 11:02:11 UTC (rev 12050)
+++ trunk/openlayers/lib/OpenLayers/Handler/Box.js	2011-06-06 11:43:50 UTC (rev 12051)
@@ -43,12 +43,16 @@
      *
      * Parameters:
      * control - {<OpenLayers.Control>} 
      * callbacks - {Object} An object with a "done" property whose value is a
      *     callback to be called when the box drag operation is finished.  
      *     The callback should expect to recieve a single argument, the box 
      *     bounds or a pixel. If the box dragging didn't span more than a 5 
      *     pixel distance, a pixel will be returned instead of a bounds object.
-     * options - {Object} 
      */
     initialize: function(control, callbacks, options) {
         OpenLayers.Handler.prototype.initialize.apply(this, arguments);
@@ -89,9 +93,10 @@
     * Method: startBox
     *
     * Parameters:
-    * evt - {Event} 
+    * xy - {<OpenLayers.Pixel>}
     */
     startBox: function (xy) {
+        this.callback("start", []);
         this.zoomBox = OpenLayers.Util.createDiv('zoomBox',
              new OpenLayers.Pixel(-9999, -9999));
         this.zoomBox.className = this.boxDivClassName;                                         
@@ -43,12 +43,16 @@
      * Parameters:
      * control - {<OpenLayers.Control>} 
-     * callbacks - {Object} An object with a "done" property whose value is a
-     *     callback to be called when the box drag operation is finished.  
-     *     The callback should expect to recieve a single argument, the box 
+     * callbacks - {Object} An object with a properties whose values are
+     *     functions.  Various callbacks described below.
+     * options - {Object} 
+     *
+     * Named callbacks:
+     * start - Called when the box drag operation starts.
+     * done - Called when the box drag operation is finished.
+     *     The callback should expect to receive a single argument, the box 
      *     bounds or a pixel. If the box dragging didn't span more than a 5 
      *     pixel distance, a pixel will be returned instead of a bounds object.

Modified: trunk/openlayers/tests/Handler/Box.html
===================================================================